package
Version:
v0.0.0-...-c9337a5
Opens a new window with list of versions in this module.
Published: Dec 20, 2017
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Version struct {
Version string `json:"version"`
GitCommit string `json:"commit"`
BuildDate string `json:"build_date"`
GoVersion string `json:"go_version"`
Platform string `json:"platform"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.