Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ErrorConnectionFailed ¶
ErrorConnectionFailed returns an error with host in the error message when connection to docker daemon failed.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is the API client that performs all operations against a docker server.
func (*Client) ExecCreate ¶
ExecCreate creates a new exec configuration to run an exec process.
func (*Client) ExecResize ¶
ExecResize changes the size of the tty for an exec process running inside a container.
type ExecConfig ¶
type ExecConfig struct {
User string
Privileged bool
Tty bool
AttachStdin bool
AttachStderr bool
AttachStdout bool
Detach bool
DetachKeys string
Env []string
Cmd []string
}
ExecConfig isi the Config struct that holds the configuration for the exec feature of docker.
type ExecResponse ¶
type ExecResponse struct {
ID string
}
ExecResponse represents response of exec api.
Click to show internal directories.
Click to hide internal directories.